# wakatime-api
REST API for accessing your WakaTime coding activity stats. - Uses GET for retrieval, POST/PUT/PATCH for modification. - All requests must use HTTPS. - Responses are JSON objects. Data is in the `data` key, errors in `error` or `errors`. - Refer to WakaTime usage guidelines when using the trademark or logo. 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://wakatime.com/contact](https://wakatime.com/contact)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install wakatime-api
```
(you may need to run `pip` with root permission: `sudo pip install wakatime-api`)

Then import the package:
```python
import wakatime_api 
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import wakatime_api
from wakatime_api.rest import ApiException
from pprint import pprint

# Configure API key authorization: apiKeyQuery
configuration = wakatime_api.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'# Configure HTTP basic authorization: basicAuth
configuration = wakatime_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'
# Configure OAuth2 access token for authorization: oauth2
configuration = wakatime_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = wakatime_api.CommitsApi(wakatime_api.ApiClient(configuration))
user = 'user_example' # str | User ID or 'current' for the authenticated user.
project = 'project_example' # str | Project ID or name (URL encoded).
hash = 'hash_example' # str | Commit hash.
branch = 'branch_example' # str | Filter by branch name. (optional)

try:
    # Get Single Commit
    api_response = api_instance.get_commit(user, project, hash, branch=branch)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CommitsApi->get_commit: %s\n" % e)

# Configure API key authorization: apiKeyQuery
configuration = wakatime_api.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'# Configure HTTP basic authorization: basicAuth
configuration = wakatime_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'
# Configure OAuth2 access token for authorization: oauth2
configuration = wakatime_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = wakatime_api.CommitsApi(wakatime_api.ApiClient(configuration))
project = 'project_example' # str | Project ID or name (URL encoded).
hash = 'hash_example' # str | Commit hash.
branch = 'branch_example' # str | Filter by branch name. (optional)

try:
    # Get Current User's Single Commit
    api_response = api_instance.get_current_user_commit(project, hash, branch=branch)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CommitsApi->get_current_user_commit: %s\n" % e)

# Configure API key authorization: apiKeyQuery
configuration = wakatime_api.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'# Configure HTTP basic authorization: basicAuth
configuration = wakatime_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'
# Configure OAuth2 access token for authorization: oauth2
configuration = wakatime_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = wakatime_api.CommitsApi(wakatime_api.ApiClient(configuration))
user = 'user_example' # str | User ID or 'current' for the authenticated user.
project = 'project_example' # str | Project ID or name (URL encoded).
author = 'author_example' # str | Filter commits by author username. (optional)
branch = 'branch_example' # str | Filter by branch name. (optional)
page = 1 # int | Page number for paginated results. (optional) (default to 1)

try:
    # List Project Commits
    api_response = api_instance.list_commits(user, project, author=author, branch=branch, page=page)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CommitsApi->list_commits: %s\n" % e)

# Configure API key authorization: apiKeyQuery
configuration = wakatime_api.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'# Configure HTTP basic authorization: basicAuth
configuration = wakatime_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'
# Configure OAuth2 access token for authorization: oauth2
configuration = wakatime_api.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = wakatime_api.CommitsApi(wakatime_api.ApiClient(configuration))
project = 'project_example' # str | Project ID or name (URL encoded).
author = 'author_example' # str | Filter commits by author username. (optional)
branch = 'branch_example' # str | Filter by branch name. (optional)
page = 1 # int | Page number for paginated results. (optional) (default to 1)

try:
    # List Current User's Project Commits
    api_response = api_instance.list_current_user_commits(project, author=author, branch=branch, page=page)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CommitsApi->list_current_user_commits: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.wakatime.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CommitsApi* | [**get_commit**](docs/CommitsApi.md#get_commit) | **GET** /users/{user}/projects/{project}/commits/{hash} | Get Single Commit
*CommitsApi* | [**get_current_user_commit**](docs/CommitsApi.md#get_current_user_commit) | **GET** /users/current/projects/{project}/commits/{hash} | Get Current User&#x27;s Single Commit
*CommitsApi* | [**list_commits**](docs/CommitsApi.md#list_commits) | **GET** /users/{user}/projects/{project}/commits | List Project Commits
*CommitsApi* | [**list_current_user_commits**](docs/CommitsApi.md#list_current_user_commits) | **GET** /users/current/projects/{project}/commits | List Current User&#x27;s Project Commits
*DataDumpsApi* | [**create_current_user_data_dump**](docs/DataDumpsApi.md#create_current_user_data_dump) | **POST** /users/current/data_dumps | Create Current User&#x27;s Data Dump
*DataDumpsApi* | [**create_data_dump**](docs/DataDumpsApi.md#create_data_dump) | **POST** /users/{user}/data_dumps | Create Data Dump
*DataDumpsApi* | [**list_current_user_data_dumps**](docs/DataDumpsApi.md#list_current_user_data_dumps) | **GET** /users/current/data_dumps | List Current User&#x27;s Data Dumps
*DataDumpsApi* | [**list_data_dumps**](docs/DataDumpsApi.md#list_data_dumps) | **GET** /users/{user}/data_dumps | List Data Dumps
*DurationsApi* | [**get_current_user_durations**](docs/DurationsApi.md#get_current_user_durations) | **GET** /users/current/durations | Get Current User Durations
*DurationsApi* | [**get_user_durations**](docs/DurationsApi.md#get_user_durations) | **GET** /users/{user}/durations | Get User Durations
*ExternalDurationsApi* | [**create_current_user_external_duration**](docs/ExternalDurationsApi.md#create_current_user_external_duration) | **POST** /users/current/external_durations | Create Current User External Duration
*ExternalDurationsApi* | [**create_current_user_external_durations_bulk**](docs/ExternalDurationsApi.md#create_current_user_external_durations_bulk) | **POST** /users/current/external_durations.bulk | Create Current User External Durations (Bulk)
*ExternalDurationsApi* | [**create_external_duration**](docs/ExternalDurationsApi.md#create_external_duration) | **POST** /users/{user}/external_durations | Create External Duration
*ExternalDurationsApi* | [**create_external_durations_bulk**](docs/ExternalDurationsApi.md#create_external_durations_bulk) | **POST** /users/{user}/external_durations.bulk | Create External Durations (Bulk)
*ExternalDurationsApi* | [**delete_current_user_external_durations_bulk**](docs/ExternalDurationsApi.md#delete_current_user_external_durations_bulk) | **DELETE** /users/current/external_durations.bulk | Delete Current User External Durations (Bulk)
*ExternalDurationsApi* | [**delete_external_durations_bulk**](docs/ExternalDurationsApi.md#delete_external_durations_bulk) | **DELETE** /users/{user}/external_durations.bulk | Delete External Durations (Bulk)
*ExternalDurationsApi* | [**get_current_user_external_durations**](docs/ExternalDurationsApi.md#get_current_user_external_durations) | **GET** /users/current/external_durations | Get Current User External Durations
*ExternalDurationsApi* | [**get_user_external_durations**](docs/ExternalDurationsApi.md#get_user_external_durations) | **GET** /users/{user}/external_durations | Get User External Durations
*GoalsApi* | [**get_current_user_goal**](docs/GoalsApi.md#get_current_user_goal) | **GET** /users/current/goals/{goal} | Get Current User&#x27;s Single Goal
*GoalsApi* | [**get_goal**](docs/GoalsApi.md#get_goal) | **GET** /users/{user}/goals/{goal} | Get Single Goal
*GoalsApi* | [**list_current_user_goals**](docs/GoalsApi.md#list_current_user_goals) | **GET** /users/current/goals | List Current User Goals
*GoalsApi* | [**list_goals**](docs/GoalsApi.md#list_goals) | **GET** /users/{user}/goals | List User Goals
*HeartbeatsApi* | [**create_current_user_heartbeat**](docs/HeartbeatsApi.md#create_current_user_heartbeat) | **POST** /users/current/heartbeats | Create Current User Heartbeat
*HeartbeatsApi* | [**create_current_user_heartbeats_bulk**](docs/HeartbeatsApi.md#create_current_user_heartbeats_bulk) | **POST** /users/current/heartbeats.bulk | Create Current User Heartbeats (Bulk)
*HeartbeatsApi* | [**create_heartbeat**](docs/HeartbeatsApi.md#create_heartbeat) | **POST** /users/{user}/heartbeats | Create Heartbeat
*HeartbeatsApi* | [**create_heartbeats_bulk**](docs/HeartbeatsApi.md#create_heartbeats_bulk) | **POST** /users/{user}/heartbeats.bulk | Create Heartbeats (Bulk)
*HeartbeatsApi* | [**delete_current_user_heartbeats_bulk**](docs/HeartbeatsApi.md#delete_current_user_heartbeats_bulk) | **DELETE** /users/current/heartbeats.bulk | Delete Current User Heartbeats (Bulk)
*HeartbeatsApi* | [**delete_heartbeats_bulk**](docs/HeartbeatsApi.md#delete_heartbeats_bulk) | **DELETE** /users/{user}/heartbeats.bulk | Delete Heartbeats (Bulk)
*HeartbeatsApi* | [**get_current_user_heartbeats**](docs/HeartbeatsApi.md#get_current_user_heartbeats) | **GET** /users/current/heartbeats | Get Current User Heartbeats
*HeartbeatsApi* | [**get_user_heartbeats**](docs/HeartbeatsApi.md#get_user_heartbeats) | **GET** /users/{user}/heartbeats | Get User Heartbeats
*InsightsApi* | [**get_current_user_insight**](docs/InsightsApi.md#get_current_user_insight) | **GET** /users/current/insights/{insight_type}/{range} | Get Current User Insight
*InsightsApi* | [**get_user_insight**](docs/InsightsApi.md#get_user_insight) | **GET** /users/{user}/insights/{insight_type}/{range} | Get User Insight
*LeaderboardsApi* | [**get_current_user_private_leaderboard_leaders**](docs/LeaderboardsApi.md#get_current_user_private_leaderboard_leaders) | **GET** /users/current/leaderboards/{board} | Get Current User&#x27;s Private Leaderboard Leaders
*LeaderboardsApi* | [**get_leaders**](docs/LeaderboardsApi.md#get_leaders) | **GET** /leaders | Get Public Leaders
*LeaderboardsApi* | [**get_private_leaderboard_leaders**](docs/LeaderboardsApi.md#get_private_leaderboard_leaders) | **GET** /users/{user}/leaderboards/{board} | Get Private Leaderboard Leaders
*LeaderboardsApi* | [**list_current_user_private_leaderboards**](docs/LeaderboardsApi.md#list_current_user_private_leaderboards) | **GET** /users/current/leaderboards | List Current User Private Leaderboards
*LeaderboardsApi* | [**list_private_leaderboards**](docs/LeaderboardsApi.md#list_private_leaderboards) | **GET** /users/{user}/leaderboards | List User Private Leaderboards
*MetaApi* | [**get_meta**](docs/MetaApi.md#get_meta) | **GET** /meta | Get API Meta Information
*OrganizationsApi* | [**get_current_user_org_dashboard_durations**](docs/OrganizationsApi.md#get_current_user_org_dashboard_durations) | **GET** /users/current/orgs/{org}/dashboards/{dashboard}/durations | Get Current User&#x27;s Org Dashboard Durations
*OrganizationsApi* | [**get_current_user_org_dashboard_member_durations**](docs/OrganizationsApi.md#get_current_user_org_dashboard_member_durations) | **GET** /users/current/orgs/{org}/dashboards/{dashboard}/members/{member}/durations | Get Current User&#x27;s Org Dashboard Member Durations
*OrganizationsApi* | [**get_current_user_org_dashboard_member_summaries**](docs/OrganizationsApi.md#get_current_user_org_dashboard_member_summaries) | **GET** /users/current/orgs/{org}/dashboards/{dashboard}/members/{member}/summaries | Get Current User&#x27;s Org Dashboard Member Summaries
*OrganizationsApi* | [**get_current_user_org_dashboard_summaries**](docs/OrganizationsApi.md#get_current_user_org_dashboard_summaries) | **GET** /users/current/orgs/{org}/dashboards/{dashboard}/summaries | Get Current User&#x27;s Org Dashboard Summaries
*OrganizationsApi* | [**get_org_dashboard_durations**](docs/OrganizationsApi.md#get_org_dashboard_durations) | **GET** /users/{user}/orgs/{org}/dashboards/{dashboard}/durations | Get Org Dashboard Durations
*OrganizationsApi* | [**get_org_dashboard_member_durations**](docs/OrganizationsApi.md#get_org_dashboard_member_durations) | **GET** /users/{user}/orgs/{org}/dashboards/{dashboard}/members/{member}/durations | Get Org Dashboard Member Durations
*OrganizationsApi* | [**get_org_dashboard_member_summaries**](docs/OrganizationsApi.md#get_org_dashboard_member_summaries) | **GET** /users/{user}/orgs/{org}/dashboards/{dashboard}/members/{member}/summaries | Get Org Dashboard Member Summaries
*OrganizationsApi* | [**get_org_dashboard_summaries**](docs/OrganizationsApi.md#get_org_dashboard_summaries) | **GET** /users/{user}/orgs/{org}/dashboards/{dashboard}/summaries | Get Org Dashboard Summaries
*OrganizationsApi* | [**list_current_user_org_dashboard_members**](docs/OrganizationsApi.md#list_current_user_org_dashboard_members) | **GET** /users/current/orgs/{org}/dashboards/{dashboard}/members | List Current User&#x27;s Org Dashboard Members
*OrganizationsApi* | [**list_current_user_org_dashboards**](docs/OrganizationsApi.md#list_current_user_org_dashboards) | **GET** /users/current/orgs/{org}/dashboards | List Current User&#x27;s Org Dashboards
*OrganizationsApi* | [**list_current_user_orgs**](docs/OrganizationsApi.md#list_current_user_orgs) | **GET** /users/current/orgs | List Current User Organizations
*OrganizationsApi* | [**list_org_dashboard_members**](docs/OrganizationsApi.md#list_org_dashboard_members) | **GET** /users/{user}/orgs/{org}/dashboards/{dashboard}/members | List Org Dashboard Members
*OrganizationsApi* | [**list_org_dashboards**](docs/OrganizationsApi.md#list_org_dashboards) | **GET** /users/{user}/orgs/{org}/dashboards | List Org Dashboards
*OrganizationsApi* | [**list_orgs**](docs/OrganizationsApi.md#list_orgs) | **GET** /users/{user}/orgs | List User Organizations
*ProjectsApi* | [**list_current_user_projects**](docs/ProjectsApi.md#list_current_user_projects) | **GET** /users/current/projects | List Current User Projects
*ProjectsApi* | [**list_projects**](docs/ProjectsApi.md#list_projects) | **GET** /users/{user}/projects | List User Projects
*ResourcesApi* | [**list_editors**](docs/ResourcesApi.md#list_editors) | **GET** /editors | List Editors
*ResourcesApi* | [**list_program_languages**](docs/ResourcesApi.md#list_program_languages) | **GET** /program_languages | List Programming Languages
*StatsApi* | [**get_aggregate_stats**](docs/StatsApi.md#get_aggregate_stats) | **GET** /stats/{range} | Get Aggregate Stats
*StatsApi* | [**get_all_time_since_today**](docs/StatsApi.md#get_all_time_since_today) | **GET** /users/{user}/all_time_since_today | Get All Time Since Today
*StatsApi* | [**get_current_user_all_time_since_today**](docs/StatsApi.md#get_current_user_all_time_since_today) | **GET** /users/current/all_time_since_today | Get Current User&#x27;s All Time Since Today
*StatsApi* | [**get_current_user_stats_default_range**](docs/StatsApi.md#get_current_user_stats_default_range) | **GET** /users/current/stats | Get Current User Stats (Default Range)
*StatsApi* | [**get_current_user_stats_for_range**](docs/StatsApi.md#get_current_user_stats_for_range) | **GET** /users/current/stats/{range} | Get Current User Stats (Specific Range)
*StatsApi* | [**get_user_stats_default_range**](docs/StatsApi.md#get_user_stats_default_range) | **GET** /users/{user}/stats | Get User Stats (Default Range)
*StatsApi* | [**get_user_stats_for_range**](docs/StatsApi.md#get_user_stats_for_range) | **GET** /users/{user}/stats/{range} | Get User Stats (Specific Range)
*SummariesApi* | [**get_current_user_status_bar_summary**](docs/SummariesApi.md#get_current_user_status_bar_summary) | **GET** /users/current/status_bar/today | Get Current User Status Bar Summary (Today)
*SummariesApi* | [**get_current_user_summaries**](docs/SummariesApi.md#get_current_user_summaries) | **GET** /users/current/summaries | Get Current User Summaries
*SummariesApi* | [**get_user_status_bar_summary**](docs/SummariesApi.md#get_user_status_bar_summary) | **GET** /users/{user}/status_bar/today | Get User Status Bar Summary (Today)
*SummariesApi* | [**get_user_summaries**](docs/SummariesApi.md#get_user_summaries) | **GET** /users/{user}/summaries | Get User Summaries
*UsersApi* | [**get_current_user**](docs/UsersApi.md#get_current_user) | **GET** /users/current | Get Current User Details
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /users/{user} | Get User Details
*UsersApi* | [**list_current_user_agents**](docs/UsersApi.md#list_current_user_agents) | **GET** /users/current/user_agents | List Current User Agents
*UsersApi* | [**list_current_user_machine_names**](docs/UsersApi.md#list_current_user_machine_names) | **GET** /users/current/machine_names | List Current User Machine Names
*UsersApi* | [**list_machine_names**](docs/UsersApi.md#list_machine_names) | **GET** /users/{user}/machine_names | List User Machine Names
*UsersApi* | [**list_user_agents**](docs/UsersApi.md#list_user_agents) | **GET** /users/{user}/user_agents | List User Agents

## Documentation For Models

 - [AggregateDailyAverage](docs/AggregateDailyAverage.md)
 - [AggregateStatCount](docs/AggregateStatCount.md)
 - [AggregateStatItem](docs/AggregateStatItem.md)
 - [AggregateStatValue](docs/AggregateStatValue.md)
 - [AggregateStats](docs/AggregateStats.md)
 - [AggregateTotal](docs/AggregateTotal.md)
 - [AllTimeSinceToday](docs/AllTimeSinceToday.md)
 - [BranchStat](docs/BranchStat.md)
 - [BulkDeleteRequest](docs/BulkDeleteRequest.md)
 - [CategoryStat](docs/CategoryStat.md)
 - [City](docs/City.md)
 - [Commit](docs/Commit.md)
 - [CommitDetailResponse](docs/CommitDetailResponse.md)
 - [CommitsListResponse](docs/CommitsListResponse.md)
 - [CumulativeTotal](docs/CumulativeTotal.md)
 - [DailyAverage](docs/DailyAverage.md)
 - [DataDump](docs/DataDump.md)
 - [DataDumpRequest](docs/DataDumpRequest.md)
 - [DependencyStat](docs/DependencyStat.md)
 - [Duration](docs/Duration.md)
 - [DurationsResponse](docs/DurationsResponse.md)
 - [EditorResource](docs/EditorResource.md)
 - [EditorStat](docs/EditorStat.md)
 - [EntityStat](docs/EntityStat.md)
 - [Error](docs/Error.md)
 - [ExternalDuration](docs/ExternalDuration.md)
 - [ExternalDurationRequest](docs/ExternalDurationRequest.md)
 - [ExternalDurationsResponse](docs/ExternalDurationsResponse.md)
 - [Goal](docs/Goal.md)
 - [GoalChartData](docs/GoalChartData.md)
 - [GoalDetailResponse](docs/GoalDetailResponse.md)
 - [GoalSharedWith](docs/GoalSharedWith.md)
 - [GoalSubscriber](docs/GoalSubscriber.md)
 - [GoalsListResponse](docs/GoalsListResponse.md)
 - [GrandTotal](docs/GrandTotal.md)
 - [Heartbeat](docs/Heartbeat.md)
 - [HeartbeatPostResponseData](docs/HeartbeatPostResponseData.md)
 - [HeartbeatRequest](docs/HeartbeatRequest.md)
 - [HeartbeatsResponse](docs/HeartbeatsResponse.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse20010](docs/InlineResponse20010.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [InlineResponse2004](docs/InlineResponse2004.md)
 - [InlineResponse2005](docs/InlineResponse2005.md)
 - [InlineResponse2006](docs/InlineResponse2006.md)
 - [InlineResponse2007](docs/InlineResponse2007.md)
 - [InlineResponse2008](docs/InlineResponse2008.md)
 - [InlineResponse2009](docs/InlineResponse2009.md)
 - [InlineResponse201](docs/InlineResponse201.md)
 - [InlineResponse2011](docs/InlineResponse2011.md)
 - [InlineResponse2012](docs/InlineResponse2012.md)
 - [InlineResponse2013](docs/InlineResponse2013.md)
 - [InlineResponse202](docs/InlineResponse202.md)
 - [Insight](docs/Insight.md)
 - [InsightResponse](docs/InsightResponse.md)
 - [InsightResponseData](docs/InsightResponseData.md)
 - [LanguageStat](docs/LanguageStat.md)
 - [Leader](docs/Leader.md)
 - [LeaderRunningTotal](docs/LeaderRunningTotal.md)
 - [LeaderRunningTotalLanguages](docs/LeaderRunningTotalLanguages.md)
 - [LeadersResponse](docs/LeadersResponse.md)
 - [LeadersResponseCurrentUser](docs/LeadersResponseCurrentUser.md)
 - [MachineName](docs/MachineName.md)
 - [MachineStat](docs/MachineStat.md)
 - [MetaResponseData](docs/MetaResponseData.md)
 - [MetaResponseDataIps](docs/MetaResponseDataIps.md)
 - [OperatingSystemStat](docs/OperatingSystemStat.md)
 - [Org](docs/Org.md)
 - [OrgDashboard](docs/OrgDashboard.md)
 - [OrgDashboardDurationMember](docs/OrgDashboardDurationMember.md)
 - [OrgDashboardDurationsResponse](docs/OrgDashboardDurationsResponse.md)
 - [OrgDashboardMember](docs/OrgDashboardMember.md)
 - [OrgDashboardMemberDurationsResponse](docs/OrgDashboardMemberDurationsResponse.md)
 - [OrgDashboardMemberListItem](docs/OrgDashboardMemberListItem.md)
 - [OrgDashboardMemberSummaryResponse](docs/OrgDashboardMemberSummaryResponse.md)
 - [OrgDashboardMembersListResponse](docs/OrgDashboardMembersListResponse.md)
 - [OrgDashboardSummariesResponse](docs/OrgDashboardSummariesResponse.md)
 - [OrgDashboardSummaryMember](docs/OrgDashboardSummaryMember.md)
 - [OrgDashboardsListResponse](docs/OrgDashboardsListResponse.md)
 - [OrgsListResponse](docs/OrgsListResponse.md)
 - [PrivateLeaderboard](docs/PrivateLeaderboard.md)
 - [PrivateLeaderboardLeadersResponse](docs/PrivateLeaderboardLeadersResponse.md)
 - [PrivateLeaderboardMember](docs/PrivateLeaderboardMember.md)
 - [PrivateLeaderboardsListResponse](docs/PrivateLeaderboardsListResponse.md)
 - [ProgramLanguage](docs/ProgramLanguage.md)
 - [ProgramLanguagesListResponse](docs/ProgramLanguagesListResponse.md)
 - [Project](docs/Project.md)
 - [ProjectStat](docs/ProjectStat.md)
 - [ProjectSummary](docs/ProjectSummary.md)
 - [Range](docs/Range.md)
 - [Repository](docs/Repository.md)
 - [Stats](docs/Stats.md)
 - [StatsBestDay](docs/StatsBestDay.md)
 - [StatusBarResponse](docs/StatusBarResponse.md)
 - [SummariesResponse](docs/SummariesResponse.md)
 - [Summary](docs/Summary.md)
 - [User](docs/User.md)
 - [UserAgent](docs/UserAgent.md)
 - [UserSummary](docs/UserSummary.md)
 - [Weekday](docs/Weekday.md)

## Documentation For Authorization


## apiKeyQuery

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: URL query string

## basicAuth

- **Type**: HTTP basic authentication

## oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://wakatime.com/oauth/authorize
- **Scopes**: 
 - **read_summaries**: Access Summaries and Stats (categories, dependencies, editors, languages, machines, operating systems, projects).
 - **read_summaries.categories**: Access Summaries and Stats (limited to categories).
 - **read_summaries.dependencies**: Access Summaries and Stats (limited to dependencies).
 - **read_summaries.editors**: Access Summaries and Stats (limited to editors).
 - **read_summaries.languages**: Access Summaries and Stats (limited to languages).
 - **read_summaries.machines**: Access Summaries and Stats (limited to machines).
 - **read_summaries.operating_systems**: Access Summaries and Stats (limited to operating systems).
 - **read_summaries.projects**: Access Summaries and Stats (limited to projects).
 - **read_stats**: Access Stats (categories, dependencies, editors, languages, machines, operating systems, projects).
 - **read_stats.best_day**: Access Stats (limited to best day).
 - **read_stats.categories**: Access Stats (limited to categories).
 - **read_stats.dependencies**: Access Stats (limited to dependencies).
 - **read_stats.editors**: Access Stats (limited to editors).
 - **read_stats.languages**: Access Stats (limited to languages).
 - **read_stats.machines**: Access Stats (limited to machines).
 - **read_stats.operating_systems**: Access Stats (limited to operating systems).
 - **read_stats.projects**: Access Stats (limited to projects).
 - **read_goals**: Access Goals.
 - **read_orgs**: Access organizations and dashboard member activity.
 - **write_orgs**: Modify organizations and dashboards.
 - **read_private_leaderboards**: Access private leaderboards.
 - **write_private_leaderboards**: Modify private leaderboards.
 - **read_heartbeats**: Access coding activity, projects, files, editors, languages, OS, dependencies, Stats, Durations, External Durations, and Heartbeats.
 - **write_heartbeats**: Modify coding activity (create, edit, delete Heartbeats and External Durations).
 - **email**: Access user&#x27;s private email address.


## Author


